@@ -995,7 +995,8 @@ def fuse_spans(output_tokens: List[Token]) -> List[Borrowing]:
     for i, token in enumerate(output_tokens):
         if token.has_outside_label():
             if half_boiled_label:
-                bor = Borrowing(half_boiled_token, half_boiled_label, start_pos, i, output_tokens)
+                bor = Borrowing.from_span(half_boiled_token, half_boiled_label, start_pos, i,
+                                   output_tokens)
                 new_output.append(bor)
                 half_boiled_label = None
                 half_boiled_token = []
@@ -1003,7 +1004,7 @@ def fuse_spans(output_tokens: List[Token]) -> List[Borrowing]:
             #new_output.append((token, label))
         if token.has_begin_label():
             if half_boiled_label:
-                bor = Borrowing(half_boiled_token, half_boiled_label, start_pos, i, output_tokens)
+                bor = Borrowing.from_span(half_boiled_token, half_boiled_label, start_pos, i, output_tokens)
                 new_output.append(bor)
             half_boiled_label = token.lang_label
             half_boiled_token = [token]
@@ -1014,6 +1015,6 @@ def fuse_spans(output_tokens: List[Token]) -> List[Borrowing]:
                 start_pos = i
             half_boiled_token.append(token)
     if half_boiled_label:
-        bor = Borrowing(half_boiled_token, half_boiled_label, start_pos, len(output_tokens), output_tokens)
+        bor = Borrowing.from_span(half_boiled_token, half_boiled_label, start_pos, len(output_tokens), output_tokens)
         new_output.append(bor)
     return new_output
